@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 12940 2021-06-03 15:19:56Z Lavender $
+# $Id: Backends.py 13011 2021-06-26 08:27:23Z Casey $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2021-06-03 23:19:56 +0800 (Thu, 03 Jun 2021) $
-# $Revision: 12940 $
+# $Author: Casey $
+# $Date: 2021-06-26 16:27:23 +0800 (Sat, 26 Jun 2021) $
+# $Revision: 13011 $
 
 import re
 import os
@@ -24,6 +24,7 @@ import requests
 from passlib.apache import HtpasswdFile
 
 from django.conf import settings
+from django.core.exceptions import PermissionDenied
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
 
@@ -46,7 +47,7 @@ class TracBackend(ModelBackend):
         data = {g[0]: json.loads(g[1]) for g in prog.findall(content)}
         ht = HtpasswdFile.from_string(content)
         if not data.get(username, {}).get("email"):
-            raise RuntimeError("No email in htfile for %s" % username)
+            raise PermissionDenied("No email in htfile for %s" % username)
         else:
             email = data.get(username, {}).get("email")
         if ht.check_password(username, password):
